/****************************************************************************
** Meta object code from reading C++ file 'theme.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../theme.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'theme.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Theme_t {
    QByteArrayData data[70];
    char stringdata0[1295];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Theme_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Theme_t qt_meta_stringdata_Theme = {
    {
QT_MOC_LITERAL(0, 0, 5), // "Theme"
QT_MOC_LITERAL(1, 6, 11), // "themeUpdate"
QT_MOC_LITERAL(2, 18, 0), // ""
QT_MOC_LITERAL(3, 19, 21), // "itemWidthLargeChanged"
QT_MOC_LITERAL(4, 41, 22), // "itemWidthMediumChanged"
QT_MOC_LITERAL(5, 64, 21), // "itemWidthSmallChanged"
QT_MOC_LITERAL(6, 86, 26), // "itemWidthExtraSmallChanged"
QT_MOC_LITERAL(7, 113, 21), // "itemHeightHugeChanged"
QT_MOC_LITERAL(8, 135, 27), // "itemHeightExtraLargeChanged"
QT_MOC_LITERAL(9, 163, 22), // "itemHeightLargeChanged"
QT_MOC_LITERAL(10, 186, 23), // "itemHeightMediumChanged"
QT_MOC_LITERAL(11, 210, 22), // "itemHeightSmallChanged"
QT_MOC_LITERAL(12, 233, 27), // "itemHeightExtraSmallChanged"
QT_MOC_LITERAL(13, 261, 22), // "itemSpacingHugeChanged"
QT_MOC_LITERAL(14, 284, 23), // "itemSpacingLargeChanged"
QT_MOC_LITERAL(15, 308, 24), // "itemSpacingMediumChanged"
QT_MOC_LITERAL(16, 333, 23), // "itemSpacingSmallChanged"
QT_MOC_LITERAL(17, 357, 28), // "itemSpacingExtraSmallChanged"
QT_MOC_LITERAL(18, 386, 25), // "fontSizeExtraLargeChanged"
QT_MOC_LITERAL(19, 412, 20), // "fontSizeLargeChanged"
QT_MOC_LITERAL(20, 433, 21), // "fontSizeMediumChanged"
QT_MOC_LITERAL(21, 455, 20), // "fontSizeSmallChanged"
QT_MOC_LITERAL(22, 476, 19), // "fontSizeTinyChanged"
QT_MOC_LITERAL(23, 496, 22), // "fontWeightLargeChanged"
QT_MOC_LITERAL(24, 519, 23), // "fontWeightMediumChanged"
QT_MOC_LITERAL(25, 543, 17), // "fontFamilyChanged"
QT_MOC_LITERAL(26, 561, 18), // "accentColorChanged"
QT_MOC_LITERAL(27, 580, 16), // "fillColorChanged"
QT_MOC_LITERAL(28, 597, 20), // "fillDarkColorChanged"
QT_MOC_LITERAL(29, 618, 16), // "textColorChanged"
QT_MOC_LITERAL(30, 635, 22), // "backgroundColorChanged"
QT_MOC_LITERAL(31, 658, 28), // "backgroundAccentColorChanged"
QT_MOC_LITERAL(32, 687, 23), // "iconSizeLauncherChanged"
QT_MOC_LITERAL(33, 711, 18), // "desktopModeChanged"
QT_MOC_LITERAL(34, 730, 23), // "desktopModeValueChanged"
QT_MOC_LITERAL(35, 754, 17), // "themeValueChanged"
QT_MOC_LITERAL(36, 772, 9), // "loadTheme"
QT_MOC_LITERAL(37, 782, 8), // "fileName"
QT_MOC_LITERAL(38, 791, 16), // "iconSizeLauncher"
QT_MOC_LITERAL(39, 808, 14), // "itemWidthLarge"
QT_MOC_LITERAL(40, 823, 15), // "itemWidthMedium"
QT_MOC_LITERAL(41, 839, 14), // "itemWidthSmall"
QT_MOC_LITERAL(42, 854, 19), // "itemWidthExtraSmall"
QT_MOC_LITERAL(43, 874, 14), // "itemHeightHuge"
QT_MOC_LITERAL(44, 889, 20), // "itemHeightExtraLarge"
QT_MOC_LITERAL(45, 910, 15), // "itemHeightLarge"
QT_MOC_LITERAL(46, 926, 16), // "itemHeightMedium"
QT_MOC_LITERAL(47, 943, 15), // "itemHeightSmall"
QT_MOC_LITERAL(48, 959, 20), // "itemHeightExtraSmall"
QT_MOC_LITERAL(49, 980, 15), // "itemSpacingHuge"
QT_MOC_LITERAL(50, 996, 16), // "itemSpacingLarge"
QT_MOC_LITERAL(51, 1013, 17), // "itemSpacingMedium"
QT_MOC_LITERAL(52, 1031, 16), // "itemSpacingSmall"
QT_MOC_LITERAL(53, 1048, 21), // "itemSpacingExtraSmall"
QT_MOC_LITERAL(54, 1070, 18), // "fontSizeExtraLarge"
QT_MOC_LITERAL(55, 1089, 13), // "fontSizeLarge"
QT_MOC_LITERAL(56, 1103, 14), // "fontSizeMedium"
QT_MOC_LITERAL(57, 1118, 13), // "fontSizeSmall"
QT_MOC_LITERAL(58, 1132, 12), // "fontSizeTiny"
QT_MOC_LITERAL(59, 1145, 15), // "fontWeightLarge"
QT_MOC_LITERAL(60, 1161, 16), // "fontWeightMedium"
QT_MOC_LITERAL(61, 1178, 10), // "fontFamily"
QT_MOC_LITERAL(62, 1189, 11), // "accentColor"
QT_MOC_LITERAL(63, 1201, 9), // "fillColor"
QT_MOC_LITERAL(64, 1211, 13), // "fillDarkColor"
QT_MOC_LITERAL(65, 1225, 9), // "textColor"
QT_MOC_LITERAL(66, 1235, 15), // "backgroundColor"
QT_MOC_LITERAL(67, 1251, 21), // "backgroundAccentColor"
QT_MOC_LITERAL(68, 1273, 11), // "desktopMode"
QT_MOC_LITERAL(69, 1285, 9) // "themePath"

    },
    "Theme\0themeUpdate\0\0itemWidthLargeChanged\0"
    "itemWidthMediumChanged\0itemWidthSmallChanged\0"
    "itemWidthExtraSmallChanged\0"
    "itemHeightHugeChanged\0itemHeightExtraLargeChanged\0"
    "itemHeightLargeChanged\0itemHeightMediumChanged\0"
    "itemHeightSmallChanged\0"
    "itemHeightExtraSmallChanged\0"
    "itemSpacingHugeChanged\0itemSpacingLargeChanged\0"
    "itemSpacingMediumChanged\0"
    "itemSpacingSmallChanged\0"
    "itemSpacingExtraSmallChanged\0"
    "fontSizeExtraLargeChanged\0"
    "fontSizeLargeChanged\0fontSizeMediumChanged\0"
    "fontSizeSmallChanged\0fontSizeTinyChanged\0"
    "fontWeightLargeChanged\0fontWeightMediumChanged\0"
    "fontFamilyChanged\0accentColorChanged\0"
    "fillColorChanged\0fillDarkColorChanged\0"
    "textColorChanged\0backgroundColorChanged\0"
    "backgroundAccentColorChanged\0"
    "iconSizeLauncherChanged\0desktopModeChanged\0"
    "desktopModeValueChanged\0themeValueChanged\0"
    "loadTheme\0fileName\0iconSizeLauncher\0"
    "itemWidthLarge\0itemWidthMedium\0"
    "itemWidthSmall\0itemWidthExtraSmall\0"
    "itemHeightHuge\0itemHeightExtraLarge\0"
    "itemHeightLarge\0itemHeightMedium\0"
    "itemHeightSmall\0itemHeightExtraSmall\0"
    "itemSpacingHuge\0itemSpacingLarge\0"
    "itemSpacingMedium\0itemSpacingSmall\0"
    "itemSpacingExtraSmall\0fontSizeExtraLarge\0"
    "fontSizeLarge\0fontSizeMedium\0fontSizeSmall\0"
    "fontSizeTiny\0fontWeightLarge\0"
    "fontWeightMedium\0fontFamily\0accentColor\0"
    "fillColor\0fillDarkColor\0textColor\0"
    "backgroundColor\0backgroundAccentColor\0"
    "desktopMode\0themePath"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Theme[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      35,   14, // methods
      32,  226, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      32,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  189,    2, 0x06 /* Public */,
       3,    0,  190,    2, 0x06 /* Public */,
       4,    0,  191,    2, 0x06 /* Public */,
       5,    0,  192,    2, 0x06 /* Public */,
       6,    0,  193,    2, 0x06 /* Public */,
       7,    0,  194,    2, 0x06 /* Public */,
       8,    0,  195,    2, 0x06 /* Public */,
       9,    0,  196,    2, 0x06 /* Public */,
      10,    0,  197,    2, 0x06 /* Public */,
      11,    0,  198,    2, 0x06 /* Public */,
      12,    0,  199,    2, 0x06 /* Public */,
      13,    0,  200,    2, 0x06 /* Public */,
      14,    0,  201,    2, 0x06 /* Public */,
      15,    0,  202,    2, 0x06 /* Public */,
      16,    0,  203,    2, 0x06 /* Public */,
      17,    0,  204,    2, 0x06 /* Public */,
      18,    0,  205,    2, 0x06 /* Public */,
      19,    0,  206,    2, 0x06 /* Public */,
      20,    0,  207,    2, 0x06 /* Public */,
      21,    0,  208,    2, 0x06 /* Public */,
      22,    0,  209,    2, 0x06 /* Public */,
      23,    0,  210,    2, 0x06 /* Public */,
      24,    0,  211,    2, 0x06 /* Public */,
      25,    0,  212,    2, 0x06 /* Public */,
      26,    0,  213,    2, 0x06 /* Public */,
      27,    0,  214,    2, 0x06 /* Public */,
      28,    0,  215,    2, 0x06 /* Public */,
      29,    0,  216,    2, 0x06 /* Public */,
      30,    0,  217,    2, 0x06 /* Public */,
      31,    0,  218,    2, 0x06 /* Public */,
      32,    0,  219,    2, 0x06 /* Public */,
      33,    0,  220,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      34,    0,  221,    2, 0x08 /* Private */,
      35,    0,  222,    2, 0x08 /* Private */,

 // methods: name, argc, parameters, tag, flags
      36,    1,  223,    2, 0x02 /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

 // methods: parameters
    QMetaType::Bool, QMetaType::QString,   37,

 // properties: name, type, flags
      38, QMetaType::QReal, 0x00495001,
      39, QMetaType::QReal, 0x00495001,
      40, QMetaType::QReal, 0x00495001,
      41, QMetaType::QReal, 0x00495001,
      42, QMetaType::QReal, 0x00495001,
      43, QMetaType::QReal, 0x00495001,
      44, QMetaType::QReal, 0x00495001,
      45, QMetaType::QReal, 0x00495001,
      46, QMetaType::QReal, 0x00495001,
      47, QMetaType::QReal, 0x00495001,
      48, QMetaType::QReal, 0x00495001,
      49, QMetaType::QReal, 0x00495001,
      50, QMetaType::QReal, 0x00495001,
      51, QMetaType::QReal, 0x00495001,
      52, QMetaType::QReal, 0x00495001,
      53, QMetaType::QReal, 0x00495001,
      54, QMetaType::Int, 0x00495001,
      55, QMetaType::Int, 0x00495001,
      56, QMetaType::Int, 0x00495001,
      57, QMetaType::Int, 0x00495001,
      58, QMetaType::Int, 0x00495001,
      59, QMetaType::Int, 0x00495001,
      60, QMetaType::Int, 0x00495001,
      61, QMetaType::QString, 0x00495001,
      62, QMetaType::QString, 0x00495001,
      63, QMetaType::QString, 0x00495001,
      64, QMetaType::QString, 0x00495001,
      65, QMetaType::QString, 0x00495001,
      66, QMetaType::QString, 0x00495001,
      67, QMetaType::QString, 0x00495001,
      68, QMetaType::Bool, 0x00495001,
      69, QMetaType::QString, 0x00495001,

 // properties: notify_signal_id
      30,
       1,
       2,
       3,
       4,
       5,
       6,
       7,
       8,
       9,
      10,
      11,
      12,
      13,
      14,
      15,
      16,
      17,
      18,
      19,
      20,
      21,
      22,
      23,
      24,
      25,
      26,
      27,
      28,
      29,
      31,
       0,

       0        // eod
};

void Theme::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<Theme *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->themeUpdate(); break;
        case 1: _t->itemWidthLargeChanged(); break;
        case 2: _t->itemWidthMediumChanged(); break;
        case 3: _t->itemWidthSmallChanged(); break;
        case 4: _t->itemWidthExtraSmallChanged(); break;
        case 5: _t->itemHeightHugeChanged(); break;
        case 6: _t->itemHeightExtraLargeChanged(); break;
        case 7: _t->itemHeightLargeChanged(); break;
        case 8: _t->itemHeightMediumChanged(); break;
        case 9: _t->itemHeightSmallChanged(); break;
        case 10: _t->itemHeightExtraSmallChanged(); break;
        case 11: _t->itemSpacingHugeChanged(); break;
        case 12: _t->itemSpacingLargeChanged(); break;
        case 13: _t->itemSpacingMediumChanged(); break;
        case 14: _t->itemSpacingSmallChanged(); break;
        case 15: _t->itemSpacingExtraSmallChanged(); break;
        case 16: _t->fontSizeExtraLargeChanged(); break;
        case 17: _t->fontSizeLargeChanged(); break;
        case 18: _t->fontSizeMediumChanged(); break;
        case 19: _t->fontSizeSmallChanged(); break;
        case 20: _t->fontSizeTinyChanged(); break;
        case 21: _t->fontWeightLargeChanged(); break;
        case 22: _t->fontWeightMediumChanged(); break;
        case 23: _t->fontFamilyChanged(); break;
        case 24: _t->accentColorChanged(); break;
        case 25: _t->fillColorChanged(); break;
        case 26: _t->fillDarkColorChanged(); break;
        case 27: _t->textColorChanged(); break;
        case 28: _t->backgroundColorChanged(); break;
        case 29: _t->backgroundAccentColorChanged(); break;
        case 30: _t->iconSizeLauncherChanged(); break;
        case 31: _t->desktopModeChanged(); break;
        case 32: _t->desktopModeValueChanged(); break;
        case 33: _t->themeValueChanged(); break;
        case 34: { bool _r = _t->loadTheme((*reinterpret_cast< QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::themeUpdate)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemWidthLargeChanged)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemWidthMediumChanged)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemWidthSmallChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemWidthExtraSmallChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemHeightHugeChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemHeightExtraLargeChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemHeightLargeChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemHeightMediumChanged)) {
                *result = 8;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemHeightSmallChanged)) {
                *result = 9;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemHeightExtraSmallChanged)) {
                *result = 10;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemSpacingHugeChanged)) {
                *result = 11;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemSpacingLargeChanged)) {
                *result = 12;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemSpacingMediumChanged)) {
                *result = 13;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemSpacingSmallChanged)) {
                *result = 14;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::itemSpacingExtraSmallChanged)) {
                *result = 15;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontSizeExtraLargeChanged)) {
                *result = 16;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontSizeLargeChanged)) {
                *result = 17;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontSizeMediumChanged)) {
                *result = 18;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontSizeSmallChanged)) {
                *result = 19;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontSizeTinyChanged)) {
                *result = 20;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontWeightLargeChanged)) {
                *result = 21;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontWeightMediumChanged)) {
                *result = 22;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fontFamilyChanged)) {
                *result = 23;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::accentColorChanged)) {
                *result = 24;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fillColorChanged)) {
                *result = 25;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::fillDarkColorChanged)) {
                *result = 26;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::textColorChanged)) {
                *result = 27;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::backgroundColorChanged)) {
                *result = 28;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::backgroundAccentColorChanged)) {
                *result = 29;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::iconSizeLauncherChanged)) {
                *result = 30;
                return;
            }
        }
        {
            using _t = void (Theme::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Theme::desktopModeChanged)) {
                *result = 31;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<Theme *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< qreal*>(_v) = _t->iconSizeLauncher(); break;
        case 1: *reinterpret_cast< qreal*>(_v) = _t->itemWidthLarge(); break;
        case 2: *reinterpret_cast< qreal*>(_v) = _t->itemWidthMedium(); break;
        case 3: *reinterpret_cast< qreal*>(_v) = _t->itemWidthSmall(); break;
        case 4: *reinterpret_cast< qreal*>(_v) = _t->itemWidthExtraSmall(); break;
        case 5: *reinterpret_cast< qreal*>(_v) = _t->itemHeightHuge(); break;
        case 6: *reinterpret_cast< qreal*>(_v) = _t->itemHeightExtraLarge(); break;
        case 7: *reinterpret_cast< qreal*>(_v) = _t->itemHeightLarge(); break;
        case 8: *reinterpret_cast< qreal*>(_v) = _t->itemHeightMedium(); break;
        case 9: *reinterpret_cast< qreal*>(_v) = _t->itemHeightSmall(); break;
        case 10: *reinterpret_cast< qreal*>(_v) = _t->itemHeightExtraSmall(); break;
        case 11: *reinterpret_cast< qreal*>(_v) = _t->itemSpacingHuge(); break;
        case 12: *reinterpret_cast< qreal*>(_v) = _t->itemSpacingLarge(); break;
        case 13: *reinterpret_cast< qreal*>(_v) = _t->itemSpacingMedium(); break;
        case 14: *reinterpret_cast< qreal*>(_v) = _t->itemSpacingSmall(); break;
        case 15: *reinterpret_cast< qreal*>(_v) = _t->itemSpacingExtraSmall(); break;
        case 16: *reinterpret_cast< int*>(_v) = _t->fontSizeExtraLarge(); break;
        case 17: *reinterpret_cast< int*>(_v) = _t->fontSizeLarge(); break;
        case 18: *reinterpret_cast< int*>(_v) = _t->fontSizeMedium(); break;
        case 19: *reinterpret_cast< int*>(_v) = _t->fontSizeSmall(); break;
        case 20: *reinterpret_cast< int*>(_v) = _t->fontSizeTiny(); break;
        case 21: *reinterpret_cast< int*>(_v) = _t->fontWeightLarge(); break;
        case 22: *reinterpret_cast< int*>(_v) = _t->fontWeightMedium(); break;
        case 23: *reinterpret_cast< QString*>(_v) = _t->fontFamily(); break;
        case 24: *reinterpret_cast< QString*>(_v) = _t->accentColor(); break;
        case 25: *reinterpret_cast< QString*>(_v) = _t->fillColor(); break;
        case 26: *reinterpret_cast< QString*>(_v) = _t->fillDarkColor(); break;
        case 27: *reinterpret_cast< QString*>(_v) = _t->textColor(); break;
        case 28: *reinterpret_cast< QString*>(_v) = _t->backgroundColor(); break;
        case 29: *reinterpret_cast< QString*>(_v) = _t->backgroundAccentColor(); break;
        case 30: *reinterpret_cast< bool*>(_v) = _t->desktopMode(); break;
        case 31: *reinterpret_cast< QString*>(_v) = _t->themePath(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject Theme::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Theme.data,
    qt_meta_data_Theme,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Theme::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Theme::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Theme.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Theme::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 35)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 35)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 35;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 32;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 32;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 32;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 32;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 32;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void Theme::themeUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Theme::itemWidthLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Theme::itemWidthMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Theme::itemWidthSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void Theme::itemWidthExtraSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Theme::itemHeightHugeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Theme::itemHeightExtraLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void Theme::itemHeightLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void Theme::itemHeightMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Theme::itemHeightSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Theme::itemHeightExtraSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Theme::itemSpacingHugeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Theme::itemSpacingLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void Theme::itemSpacingMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void Theme::itemSpacingSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Theme::itemSpacingExtraSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void Theme::fontSizeExtraLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Theme::fontSizeLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Theme::fontSizeMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void Theme::fontSizeSmallChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void Theme::fontSizeTinyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Theme::fontWeightLargeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void Theme::fontWeightMediumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Theme::fontFamilyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void Theme::accentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Theme::fillColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Theme::fillDarkColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Theme::textColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Theme::backgroundColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void Theme::backgroundAccentColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void Theme::iconSizeLauncherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void Theme::desktopModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
