/****************************************************************************
** Meta object code from reading C++ file 'qquickfilteringmousearea.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../qquickfilteringmousearea.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'qquickfilteringmousearea.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_QQuickFilteringMouseArea_t {
    QByteArrayData data[19];
    char stringdata0[253];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_QQuickFilteringMouseArea_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_QQuickFilteringMouseArea_t qt_meta_stringdata_QQuickFilteringMouseArea = {
    {
QT_MOC_LITERAL(0, 0, 24), // "QQuickFilteringMouseArea"
QT_MOC_LITERAL(1, 25, 14), // "pressedChanged"
QT_MOC_LITERAL(2, 40, 0), // ""
QT_MOC_LITERAL(3, 41, 7), // "pressed"
QT_MOC_LITERAL(4, 49, 3), // "pos"
QT_MOC_LITERAL(5, 53, 8), // "released"
QT_MOC_LITERAL(6, 62, 15), // "positionChanged"
QT_MOC_LITERAL(7, 78, 15), // "pressPosChanged"
QT_MOC_LITERAL(8, 94, 15), // "deltaPosChanged"
QT_MOC_LITERAL(9, 110, 15), // "swipingXChanged"
QT_MOC_LITERAL(10, 126, 15), // "swipingYChanged"
QT_MOC_LITERAL(11, 142, 23), // "swipingThresholdChanged"
QT_MOC_LITERAL(12, 166, 15), // "grabMouseEvents"
QT_MOC_LITERAL(13, 182, 17), // "ungrabMouseEvents"
QT_MOC_LITERAL(14, 200, 8), // "pressPos"
QT_MOC_LITERAL(15, 209, 8), // "deltaPos"
QT_MOC_LITERAL(16, 218, 8), // "swipingX"
QT_MOC_LITERAL(17, 227, 8), // "swipingY"
QT_MOC_LITERAL(18, 236, 16) // "swipingThreshold"

    },
    "QQuickFilteringMouseArea\0pressedChanged\0"
    "\0pressed\0pos\0released\0positionChanged\0"
    "pressPosChanged\0deltaPosChanged\0"
    "swipingXChanged\0swipingYChanged\0"
    "swipingThresholdChanged\0grabMouseEvents\0"
    "ungrabMouseEvents\0pressPos\0deltaPos\0"
    "swipingX\0swipingY\0swipingThreshold"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_QQuickFilteringMouseArea[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      11,   14, // methods
       6,   86, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       9,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   69,    2, 0x06 /* Public */,
       3,    1,   70,    2, 0x06 /* Public */,
       5,    1,   73,    2, 0x06 /* Public */,
       6,    1,   76,    2, 0x06 /* Public */,
       7,    0,   79,    2, 0x06 /* Public */,
       8,    0,   80,    2, 0x06 /* Public */,
       9,    0,   81,    2, 0x06 /* Public */,
      10,    0,   82,    2, 0x06 /* Public */,
      11,    0,   83,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      12,    0,   84,    2, 0x0a /* Public */,
      13,    0,   85,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::QPointF,    4,
    QMetaType::Void, QMetaType::QPointF,    4,
    QMetaType::Void, QMetaType::QPointF,    4,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

 // properties: name, type, flags
       3, QMetaType::Bool, 0x00495001,
      14, QMetaType::QPointF, 0x00495001,
      15, QMetaType::QPointF, 0x00495001,
      16, QMetaType::Bool, 0x00495001,
      17, QMetaType::Bool, 0x00495001,
      18, QMetaType::Int, 0x00495103,

 // properties: notify_signal_id
       0,
       4,
       5,
       6,
       7,
       8,

       0        // eod
};

void QQuickFilteringMouseArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<QQuickFilteringMouseArea *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->pressedChanged(); break;
        case 1: _t->pressed((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 2: _t->released((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 3: _t->positionChanged((*reinterpret_cast< const QPointF(*)>(_a[1]))); break;
        case 4: _t->pressPosChanged(); break;
        case 5: _t->deltaPosChanged(); break;
        case 6: _t->swipingXChanged(); break;
        case 7: _t->swipingYChanged(); break;
        case 8: _t->swipingThresholdChanged(); break;
        case 9: _t->grabMouseEvents(); break;
        case 10: _t->ungrabMouseEvents(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (QQuickFilteringMouseArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::pressedChanged)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::pressed)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::released)) {
                *result = 2;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)(const QPointF & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::positionChanged)) {
                *result = 3;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::pressPosChanged)) {
                *result = 4;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::deltaPosChanged)) {
                *result = 5;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::swipingXChanged)) {
                *result = 6;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::swipingYChanged)) {
                *result = 7;
                return;
            }
        }
        {
            using _t = void (QQuickFilteringMouseArea::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QQuickFilteringMouseArea::swipingThresholdChanged)) {
                *result = 8;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        auto *_t = static_cast<QQuickFilteringMouseArea *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->isPressed(); break;
        case 1: *reinterpret_cast< QPointF*>(_v) = _t->pressPos(); break;
        case 2: *reinterpret_cast< QPointF*>(_v) = _t->deltaPos(); break;
        case 3: *reinterpret_cast< bool*>(_v) = _t->isSwipingX(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isSwipingY(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->swipingThreshold(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        auto *_t = static_cast<QQuickFilteringMouseArea *>(_o);
        (void)_t;
        void *_v = _a[0];
        switch (_id) {
        case 5: _t->setSwipingThreshold(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

QT_INIT_METAOBJECT const QMetaObject QQuickFilteringMouseArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_meta_stringdata_QQuickFilteringMouseArea.data,
    qt_meta_data_QQuickFilteringMouseArea,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *QQuickFilteringMouseArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *QQuickFilteringMouseArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_QQuickFilteringMouseArea.stringdata0))
        return static_cast<void*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int QQuickFilteringMouseArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 11;
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void QQuickFilteringMouseArea::pressedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void QQuickFilteringMouseArea::pressed(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void QQuickFilteringMouseArea::released(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void QQuickFilteringMouseArea::positionChanged(const QPointF & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void QQuickFilteringMouseArea::pressPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void QQuickFilteringMouseArea::deltaPosChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void QQuickFilteringMouseArea::swipingXChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void QQuickFilteringMouseArea::swipingYChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void QQuickFilteringMouseArea::swipingThresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
