/*
 * Copyright (C) 2013 Aleksi Suomalainen <suomalainen.aleksi@gmail.com>
 * Copyright (C) 2022 Chupligin Sergey (NeoChapay) <neochapay@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */
#include "nemoimageprovider.h"

NemoImageProvider::NemoImageProvider()
    : QQuickImageProvider(QQuickImageProvider::Image)
    , m_client(new MLocalThemeDaemonClient())
{
}

QImage NemoImageProvider::requestImage(const QString& id, QSize* size, const QSize& requestedSize)
{
    Q_UNUSED(size);
    QPixmap image = m_client->requestPixmap(id, requestedSize);
    return image.toImage();
}

QPixmap NemoImageProvider::requestPixmap(const QString& id, QSize* size, const QSize& requestedSize)
{
    Q_UNUSED(size);
    return m_client->requestPixmap(id, requestedSize);
}
